(archive options & paths)Archives specified files in paths. Options:
output-stream: where to write the archived bytes tocompression: type of compression, e.g. gzarchive-type: type of archive, e.g. tarentry-name-resolver: 1-arity fn that takes the input path and outputs path to use in the archivebefore-add: 1-arity fn that can do some changes on the archive entry before storing. Useful to set file permissions for example.Archives specified files in paths. Options: - `output-stream`: where to write the archived bytes to - `compression`: type of compression, e.g. `gz` - `archive-type`: type of archive, e.g. `tar` - `entry-name-resolver`: 1-arity fn that takes the input path and outputs path to use in the archive - `before-add`: 1-arity fn that can do some changes on the archive entry before storing. Useful to set file permissions for example.
(strip-dir dir)Entry name resolver that strips the given directory from the input path
Entry name resolver that strips the given directory from the input path
Default entry name resolver that strips the leading slash from the path
Default entry name resolver that strips the leading slash from the path
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |