clompress.archivers.tar

Archiver implementation for tarballs

Archiver implementation for tarballs
raw docstring

make-archiverclj

(make-archiver output)
source

set-entry-modeclj

(set-entry-mode entry)

before-add handler that sets the TAR entry file mode using the posix file permissions. Note that this is applied by default by the TarArchiver.

`before-add` handler that sets the TAR entry file mode using the posix file permissions.
Note that this is applied by default by the `TarArchiver`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries