clompress.core


Archivercljprotocol

make-entryclj

(make-entry this entry entry-name)

Creates a new archive entry in the archive for the path

Creates a new archive entry in the archive for the path
source

Unarchivercljprotocol

extract-entryclj

(extract-entry this entry dest)

Extracts the archive entry to the given destination

Extracts the archive entry to the given destination
source

cljdoc builds & hosts documentation for Clojure/Script libraries