Functions for extracting files from archives
Functions for extracting files from archives
(entry-seq ai)Given an archive input stream, returns a lazy seq of its entries (as an ArchiveEntry).
Given an archive input stream, returns a lazy seq of its entries (as an `ArchiveEntry`).
(make-unarchiver is type)Creates an unarchiver for the given input stream and type (see available-unarchivers).
Creates an unarchiver for the given input stream and type (see `available-unarchivers`).
(unarchive {src :input-stream :as opts} dest)'Batteries included' function that unarchives the given input-stream into the dest
directory. This makes use of other functions in this ns, which may be more suitable
for specific uses. Returns a list of extracted entries.
Options:
input-stream: the input stream to read from (required)archive-type: what type of archive this is (e.g. 'tar')compression: what kind of decompression to use, if any (e.g. gz)filter-fn: predicate to decide which files to extract'Batteries included' function that unarchives the given `input-stream` into the `dest` directory. This makes use of other functions in this ns, which may be more suitable for specific uses. Returns a list of extracted entries. Options: - `input-stream`: the input stream to read from (required) - `archive-type`: what type of archive this is (e.g. 'tar') - `compression`: what kind of decompression to use, if any (e.g. `gz`) - `filter-fn`: predicate to decide which files to extract
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |